hubspotsdk

package module
v0.1.0-alpha.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: Apache-2.0 Imports: 27 Imported by: 0

README

HubSpot Go API Library

Go Reference

The HubSpot Go library provides convenient access to HubSpot date-versioned REST API (2026-03 release) from applications written in Go.

It is generated with Stainless.

Installation

import (
	"github.com/HubSpot/hubspot-sdk-go" // imported as hubspotsdk
)

Or to pin the version:

go get -u 'github.com/HubSpot/hubspot-sdk-go@v0.1.0-alpha.2'

Requirements

This library requires Go 1.22+.

Usage

The full API of this library can be found in api.md.

package main

import (
	"context"
	"fmt"

	"github.com/HubSpot/hubspot-sdk-go"
	"github.com/HubSpot/hubspot-sdk-go/crm"
	"github.com/HubSpot/hubspot-sdk-go/option"
)

func main() {
	client := hubspotsdk.NewClient(
		option.WithAccessToken("My Access Token"),
	)
	result, err := client.Crm.Objects.Contacts.Get(
		context.TODO(),
		"contactId",
		crm.ObjectContactGetParams{},
	)
	if err != nil {
		panic(err.Error())
	}
	fmt.Printf("%+v\n", result.ID)
}

Request fields

The hubspotsdk library uses the omitzero semantics from the Go 1.24+ encoding/json release for request fields.

Required primitive fields (int64, string, etc.) feature the tag `api:"required"`. These fields are always serialized, even their zero values.

Optional primitive types are wrapped in a param.Opt[T]. These fields can be set with the provided constructors, hubspotsdk.String(string), hubspotsdk.Int(int64), etc.

Any param.Opt[T], map, slice, struct or string enum uses the tag `json:"...,omitzero"`. Its zero value is considered omitted.

The param.IsOmitted(any) function can confirm the presence of any omitzero field.

p := hubspotsdk.ExampleParams{
	ID:   "id_xxx",                 // required property
	Name: hubspotsdk.String("..."), // optional property

	Point: hubspotsdk.Point{
		X: 0,                 // required field will serialize as 0
		Y: hubspotsdk.Int(1), // optional field will serialize as 1
		// ... omitted non-required fields will not be serialized
	},

	Origin: hubspotsdk.Origin{}, // the zero value of [Origin] is considered omitted
}

To send null instead of a param.Opt[T], use param.Null[T](). To send null instead of a struct T, use param.NullStruct[T]().

p.Name = param.Null[string]()       // 'null' instead of string
p.Point = param.NullStruct[Point]() // 'null' instead of struct

param.IsNull(p.Name)  // true
param.IsNull(p.Point) // true

Request structs contain a .SetExtraFields(map[string]any) method which can send non-conforming fields in the request body. Extra fields overwrite any struct fields with a matching key. For security reasons, only use SetExtraFields with trusted data.

To send a custom value instead of a struct, use param.Override[T](value).

// In cases where the API specifies a given type,
// but you want to send something else, use [SetExtraFields]:
p.SetExtraFields(map[string]any{
	"x": 0.01, // send "x" as a float instead of int
})

// Send a number instead of an object
custom := param.Override[hubspotsdk.FooParams](12)
Request unions

Unions are represented as a struct with fields prefixed by "Of" for each of its variants, only one field can be non-zero. The non-zero field will be serialized.

Sub-properties of the union can be accessed via methods on the union struct. These methods return a mutable pointer to the underlying data, if present.

// Only one field can be non-zero, use param.IsOmitted() to check if a field is set
type AnimalUnionParam struct {
	OfCat *Cat `json:",omitzero,inline`
	OfDog *Dog `json:",omitzero,inline`
}

animal := AnimalUnionParam{
	OfCat: &Cat{
		Name: "Whiskers",
		Owner: PersonParam{
			Address: AddressParam{Street: "3333 Coyote Hill Rd", Zip: 0},
		},
	},
}

// Mutating a field
if address := animal.GetOwner().GetAddress(); address != nil {
	address.ZipCode = 94304
}
Response objects

All fields in response structs are ordinary value types (not pointers or wrappers). Response structs also include a special JSON field containing metadata about each property.

type Animal struct {
	Name   string `json:"name,nullable"`
	Owners int    `json:"owners"`
	Age    int    `json:"age"`
	JSON   struct {
		Name        respjson.Field
		Owner       respjson.Field
		Age         respjson.Field
		ExtraFields map[string]respjson.Field
	} `json:"-"`
}

To handle optional data, use the .Valid() method on the JSON field. .Valid() returns true if a field is not null, not present, or couldn't be marshaled.

If .Valid() is false, the corresponding field will simply be its zero value.

raw := `{"owners": 1, "name": null}`

var res Animal
json.Unmarshal([]byte(raw), &res)

// Accessing regular fields

res.Owners // 1
res.Name   // ""
res.Age    // 0

// Optional field checks

res.JSON.Owners.Valid() // true
res.JSON.Name.Valid()   // false
res.JSON.Age.Valid()    // false

// Raw JSON values

res.JSON.Owners.Raw()                  // "1"
res.JSON.Name.Raw() == "null"          // true
res.JSON.Name.Raw() == respjson.Null   // true
res.JSON.Age.Raw() == ""               // true
res.JSON.Age.Raw() == respjson.Omitted // true

These .JSON structs also include an ExtraFields map containing any properties in the json response that were not specified in the struct. This can be useful for API features not yet present in the SDK.

body := res.JSON.ExtraFields["my_unexpected_field"].Raw()
Response Unions

In responses, unions are represented by a flattened struct containing all possible fields from each of the object variants. To convert it to a variant use the .AsFooVariant() method or the .AsAny() method if present.

If a response value union contains primitive values, primitive fields will be alongside the properties but prefixed with Of and feature the tag json:"...,inline".

type AnimalUnion struct {
	// From variants [Dog], [Cat]
	Owner Person `json:"owner"`
	// From variant [Dog]
	DogBreed string `json:"dog_breed"`
	// From variant [Cat]
	CatBreed string `json:"cat_breed"`
	// ...

	JSON struct {
		Owner respjson.Field
		// ...
	} `json:"-"`
}

// If animal variant
if animal.Owner.Address.ZipCode == "" {
	panic("missing zip code")
}

// Switch on the variant
switch variant := animal.AsAny().(type) {
case Dog:
case Cat:
default:
	panic("unexpected type")
}
RequestOptions

This library uses the functional options pattern. Functions defined in the option package return a RequestOption, which is a closure that mutates a RequestConfig. These options can be supplied to the client or at individual requests. For example:

client := hubspotsdk.NewClient(
	// Adds a header to every request made by the client
	option.WithHeader("X-Some-Header", "custom_header_info"),
)

client.Crm.Objects.Contacts.New(context.TODO(), ...,
	// Override the header
	option.WithHeader("X-Some-Header", "some_other_custom_header_info"),
	// Add an undocumented field to the request body, using sjson syntax
	option.WithJSONSet("some.json.path", map[string]string{"my": "object"}),
)

The request option option.WithDebugLog(nil) may be helpful while debugging.

See the full list of request options.

Pagination

This library provides some conveniences for working with paginated list endpoints.

You can use .ListAutoPaging() methods to iterate through items across all pages:

iter := client.Crm.Objects.Contacts.ListAutoPaging(context.TODO(), crm.ObjectContactListParams{
	Limit: hubspotsdk.Int(100),
})
// Automatically fetches more pages as needed.
for iter.Next() {
	simplePublicObjectWithAssociations := iter.Current()
	fmt.Printf("%+v\n", simplePublicObjectWithAssociations)
}
if err := iter.Err(); err != nil {
	panic(err.Error())
}

Or you can use simple .List() methods to fetch a single page and receive a standard response object with additional helper methods like .GetNextPage(), e.g.:

page, err := client.Crm.Objects.Contacts.List(context.TODO(), crm.ObjectContactListParams{
	Limit: hubspotsdk.Int(100),
})
for page != nil {
	for _, contact := range page.Results {
		fmt.Printf("%+v\n", contact)
	}
	page, err = page.GetNextPage()
}
if err != nil {
	panic(err.Error())
}
Errors

When the API returns a non-success status code, we return an error with type *hubspotsdk.Error. This contains the StatusCode, *http.Request, and *http.Response values of the request, as well as the JSON of the error body (much like other response objects in the SDK).

To handle errors, we recommend that you use the errors.As pattern:

_, err := client.Crm.Objects.Contacts.New(context.TODO(), crm.ObjectContactNewParams{
	SimplePublicObjectInputForCreate: crm.SimplePublicObjectInputForCreateParam{
		Associations: []crm.PublicAssociationsForObjectParam{{
			To: shared.PublicObjectIDParam{
				ID: "id",
			},
			Types: []shared.AssociationSpecParam{{
				AssociationCategory: shared.AssociationSpecAssociationCategoryHubSpotDefined,
				AssociationTypeID:   0,
			}},
		}},
		Properties: map[string]string{
			"foo": "string",
		},
	},
})
if err != nil {
	var apierr *hubspotsdk.Error
	if errors.As(err, &apierr) {
		println(string(apierr.DumpRequest(true)))  // Prints the serialized HTTP request
		println(string(apierr.DumpResponse(true))) // Prints the serialized HTTP response
	}
	panic(err.Error()) // GET "/crm/objects/2026-03/contacts": 400 Bad Request { ... }
}

When other errors occur, they are returned unwrapped; for example, if HTTP transport fails, you might receive *url.Error wrapping *net.OpError.

Timeouts

Requests do not time out by default; use context to configure a timeout for a request lifecycle.

Note that if a request is retried, the context timeout does not start over. To set a per-retry timeout, use option.WithRequestTimeout().

// This sets the timeout for the request, including all the retries.
ctx, cancel := context.WithTimeout(context.Background(), 5*time.Minute)
defer cancel()
client.Crm.Objects.Contacts.New(
	ctx,
	crm.ObjectContactNewParams{
		SimplePublicObjectInputForCreate: crm.SimplePublicObjectInputForCreateParam{
			Associations: []crm.PublicAssociationsForObjectParam{{
				To: shared.PublicObjectIDParam{
					ID: "id",
				},
				Types: []shared.AssociationSpecParam{{
					AssociationCategory: shared.AssociationSpecAssociationCategoryHubSpotDefined,
					AssociationTypeID:   0,
				}},
			}},
			Properties: map[string]string{
				"foo": "string",
			},
		},
	},
	// This sets the per-retry timeout
	option.WithRequestTimeout(20*time.Second),
)
File uploads

Request parameters that correspond to file uploads in multipart requests are typed as io.Reader. The contents of the io.Reader will by default be sent as a multipart form part with the file name of "anonymous_file" and content-type of "application/octet-stream".

The file name and content-type can be customized by implementing Name() string or ContentType() string on the run-time type of io.Reader. Note that os.File implements Name() string, so a file returned by os.Open will be sent with the file name on disk.

We also provide a helper hubspotsdk.File(reader io.Reader, filename string, contentType string) which can be used to wrap any io.Reader with the appropriate file name and content type.

// A file from the file system
file, err := os.Open("/path/to/file")
cms.HubdbTableImportDraftParams{
	File: file,
}

// A file from a string
cms.HubdbTableImportDraftParams{
	File: strings.NewReader("my file contents"),
}

// With a custom filename and contentType
cms.HubdbTableImportDraftParams{
	File: hubspotsdk.File(strings.NewReader(`{"hello": "foo"}`), "file.go", "application/json"),
}
Retries

Certain errors will be automatically retried 2 times by default, with a short exponential backoff. We retry by default all connection errors, 408 Request Timeout, 409 Conflict, 429 Rate Limit, and >=500 Internal errors.

You can use the WithMaxRetries option to configure or disable this:

// Configure the default for all requests:
client := hubspotsdk.NewClient(
	option.WithMaxRetries(0), // default is 2
)

// Override per-request:
client.Crm.Objects.Contacts.New(
	context.TODO(),
	crm.ObjectContactNewParams{
		SimplePublicObjectInputForCreate: crm.SimplePublicObjectInputForCreateParam{
			Associations: []crm.PublicAssociationsForObjectParam{{
				To: shared.PublicObjectIDParam{
					ID: "id",
				},
				Types: []shared.AssociationSpecParam{{
					AssociationCategory: shared.AssociationSpecAssociationCategoryHubSpotDefined,
					AssociationTypeID:   0,
				}},
			}},
			Properties: map[string]string{
				"foo": "string",
			},
		},
	},
	option.WithMaxRetries(5),
)
Accessing raw response data (e.g. response headers)

You can access the raw HTTP response data by using the option.WithResponseInto() request option. This is useful when you need to examine response headers, status codes, or other details.

// Create a variable to store the HTTP response
var response *http.Response
simplePublicObject, err := client.Crm.Objects.Contacts.New(
	context.TODO(),
	crm.ObjectContactNewParams{
		SimplePublicObjectInputForCreate: crm.SimplePublicObjectInputForCreateParam{
			Associations: []crm.PublicAssociationsForObjectParam{{
				To: shared.PublicObjectIDParam{
					ID: "id",
				},
				Types: []shared.AssociationSpecParam{{
					AssociationCategory: shared.AssociationSpecAssociationCategoryHubSpotDefined,
					AssociationTypeID:   0,
				}},
			}},
			Properties: map[string]string{
				"foo": "string",
			},
		},
	},
	option.WithResponseInto(&response),
)
if err != nil {
	// handle error
}
fmt.Printf("%+v\n", simplePublicObject)

fmt.Printf("Status Code: %d\n", response.StatusCode)
fmt.Printf("Headers: %+#v\n", response.Header)
Making custom/undocumented requests

This library is typed for convenient access to the documented API. If you need to access undocumented endpoints, params, or response properties, the library can still be used.

Undocumented endpoints

To make requests to undocumented endpoints, you can use client.Get, client.Post, and other HTTP verbs. RequestOptions on the client, such as retries, will be respected when making these requests.

var (
    // params can be an io.Reader, a []byte, an encoding/json serializable object,
    // or a "…Params" struct defined in this library.
    params map[string]any

    // result can be an []byte, *http.Response, a encoding/json deserializable object,
    // or a model defined in this library.
    result *http.Response
)
err := client.Post(context.Background(), "/unspecified", params, &result)
if err != nil {
    …
}
Undocumented request params

To make requests using undocumented parameters, you may use either the option.WithQuerySet() or the option.WithJSONSet() methods.

params := FooNewParams{
    ID:   "id_xxxx",
    Data: FooNewParamsData{
        FirstName: hubspotsdk.String("John"),
    },
}
client.Foo.New(context.Background(), params, option.WithJSONSet("data.last_name", "Doe"))
Undocumented response properties

To access undocumented response properties, you may either access the raw JSON of the response as a string with result.JSON.RawJSON(), or get the raw JSON of a particular field on the result with result.JSON.Foo.Raw().

Any fields that are not present on the response struct will be saved and can be accessed by result.JSON.ExtraFields() which returns the extra fields as a map[string]Field.

Middleware

We provide option.WithMiddleware which applies the given middleware to requests.

func Logger(req *http.Request, next option.MiddlewareNext) (res *http.Response, err error) {
	// Before the request
	start := time.Now()
	LogReq(req)

	// Forward the request to the next handler
	res, err = next(req)

	// Handle stuff after the request
	end := time.Now()
	LogRes(res, err, start - end)

    return res, err
}

client := hubspotsdk.NewClient(
	option.WithMiddleware(Logger),
)

When multiple middlewares are provided as variadic arguments, the middlewares are applied left to right. If option.WithMiddleware is given multiple times, for example first in the client then the method, the middleware in the client will run first and the middleware given in the method will run next.

You may also replace the default http.Client with option.WithHTTPClient(client). Only one http client is accepted (this overwrites any previous client) and receives requests after any middleware has been applied.

Semantic versioning

This package generally follows SemVer conventions, though certain backwards-incompatible changes may be released as minor versions:

  1. Changes to library internals which are technically public but not intended or documented for external use. (Please open a GitHub issue to let us know if you are relying on such internals.)
  2. Changes that we do not expect to impact the vast majority of users in practice.

We take backwards-compatibility seriously and work hard to ensure you can rely on a smooth upgrade experience.

We are keen for your feedback; please open an issue with questions, bugs, or suggestions.

Contributing

See the contributing documentation.

Documentation

Index

Constants

const ActionResponseStatusCanceled = shared.ActionResponseStatusCanceled

Equals "CANCELED"

const ActionResponseStatusComplete = shared.ActionResponseStatusComplete

Equals "COMPLETE"

const ActionResponseStatusPending = shared.ActionResponseStatusPending

Equals "PENDING"

const ActionResponseStatusProcessing = shared.ActionResponseStatusProcessing

Equals "PROCESSING"

const AssociationSpecAssociationCategoryHubSpotDefined = shared.AssociationSpecAssociationCategoryHubSpotDefined

Equals "HUBSPOT_DEFINED"

const AssociationSpecAssociationCategoryIntegratorDefined = shared.AssociationSpecAssociationCategoryIntegratorDefined

Equals "INTEGRATOR_DEFINED"

const AssociationSpecAssociationCategoryUserDefined = shared.AssociationSpecAssociationCategoryUserDefined

Equals "USER_DEFINED"

const AssociationSpecAssociationCategoryWork = shared.AssociationSpecAssociationCategoryWork

Equals "WORK"

const BatchReadInputPropertyNameDataSensitivityHighlySensitive = shared.BatchReadInputPropertyNameDataSensitivityHighlySensitive

Equals "highly_sensitive"

const BatchReadInputPropertyNameDataSensitivityNonSensitive = shared.BatchReadInputPropertyNameDataSensitivityNonSensitive

Equals "non_sensitive"

const BatchReadInputPropertyNameDataSensitivitySensitive = shared.BatchReadInputPropertyNameDataSensitivitySensitive

Equals "sensitive"

const PropertyCreateDataSensitivityHighlySensitive = shared.PropertyCreateDataSensitivityHighlySensitive

Equals "highly_sensitive"

const PropertyCreateDataSensitivityNonSensitive = shared.PropertyCreateDataSensitivityNonSensitive

Equals "non_sensitive"

const PropertyCreateDataSensitivitySensitive = shared.PropertyCreateDataSensitivitySensitive

Equals "sensitive"

const PropertyCreateFieldTypeBooleancheckbox = shared.PropertyCreateFieldTypeBooleancheckbox

Equals "booleancheckbox"

const PropertyCreateFieldTypeCalculationEquation = shared.PropertyCreateFieldTypeCalculationEquation

Equals "calculation_equation"

const PropertyCreateFieldTypeCheckbox = shared.PropertyCreateFieldTypeCheckbox

Equals "checkbox"

const PropertyCreateFieldTypeDate = shared.PropertyCreateFieldTypeDate

Equals "date"

const PropertyCreateFieldTypeFile = shared.PropertyCreateFieldTypeFile

Equals "file"

const PropertyCreateFieldTypeHTML = shared.PropertyCreateFieldTypeHTML

Equals "html"

const PropertyCreateFieldTypeNumber = shared.PropertyCreateFieldTypeNumber

Equals "number"

const PropertyCreateFieldTypePhonenumber = shared.PropertyCreateFieldTypePhonenumber

Equals "phonenumber"

const PropertyCreateFieldTypeRadio = shared.PropertyCreateFieldTypeRadio

Equals "radio"

const PropertyCreateFieldTypeSelect = shared.PropertyCreateFieldTypeSelect

Equals "select"

const PropertyCreateFieldTypeText = shared.PropertyCreateFieldTypeText

Equals "text"

const PropertyCreateFieldTypeTextarea = shared.PropertyCreateFieldTypeTextarea

Equals "textarea"

const PropertyCreateNumberDisplayHintCurrency = shared.PropertyCreateNumberDisplayHintCurrency

Equals "currency"

const PropertyCreateNumberDisplayHintDuration = shared.PropertyCreateNumberDisplayHintDuration

Equals "duration"

const PropertyCreateNumberDisplayHintFormatted = shared.PropertyCreateNumberDisplayHintFormatted

Equals "formatted"

const PropertyCreateNumberDisplayHintPercentage = shared.PropertyCreateNumberDisplayHintPercentage

Equals "percentage"

const PropertyCreateNumberDisplayHintProbability = shared.PropertyCreateNumberDisplayHintProbability

Equals "probability"

const PropertyCreateNumberDisplayHintUnformatted = shared.PropertyCreateNumberDisplayHintUnformatted

Equals "unformatted"

const PropertyCreateTypeBool = shared.PropertyCreateTypeBool

Equals "bool"

const PropertyCreateTypeDate = shared.PropertyCreateTypeDate

Equals "date"

const PropertyCreateTypeDatetime = shared.PropertyCreateTypeDatetime

Equals "datetime"

const PropertyCreateTypeEnumeration = shared.PropertyCreateTypeEnumeration

Equals "enumeration"

const PropertyCreateTypeNumber = shared.PropertyCreateTypeNumber

Equals "number"

const PropertyCreateTypePhoneNumber = shared.PropertyCreateTypePhoneNumber

Equals "phone_number"

const PropertyCreateTypeString = shared.PropertyCreateTypeString

Equals "string"

const PropertyDataSensitivityHighlySensitive = shared.PropertyDataSensitivityHighlySensitive

Equals "highly_sensitive"

const PropertyDataSensitivityNonSensitive = shared.PropertyDataSensitivityNonSensitive

Equals "non_sensitive"

const PropertyDataSensitivitySensitive = shared.PropertyDataSensitivitySensitive

Equals "sensitive"

const PropertyDateDisplayHintAbsolute = shared.PropertyDateDisplayHintAbsolute

Equals "absolute"

const PropertyDateDisplayHintAbsoluteWithRelative = shared.PropertyDateDisplayHintAbsoluteWithRelative

Equals "absolute_with_relative"

const PropertyDateDisplayHintTimeSince = shared.PropertyDateDisplayHintTimeSince

Equals "time_since"

const PropertyDateDisplayHintTimeUntil = shared.PropertyDateDisplayHintTimeUntil

Equals "time_until"

const PropertyNumberDisplayHintCurrency = shared.PropertyNumberDisplayHintCurrency

Equals "currency"

const PropertyNumberDisplayHintDuration = shared.PropertyNumberDisplayHintDuration

Equals "duration"

const PropertyNumberDisplayHintFormatted = shared.PropertyNumberDisplayHintFormatted

Equals "formatted"

const PropertyNumberDisplayHintPercentage = shared.PropertyNumberDisplayHintPercentage

Equals "percentage"

const PropertyNumberDisplayHintProbability = shared.PropertyNumberDisplayHintProbability

Equals "probability"

const PropertyNumberDisplayHintUnformatted = shared.PropertyNumberDisplayHintUnformatted

Equals "unformatted"

const PropertyValueDataSensitivityHigh = shared.PropertyValueDataSensitivityHigh

Equals "high"

const PropertyValueDataSensitivityNone = shared.PropertyValueDataSensitivityNone

Equals "none"

const PropertyValueDataSensitivityStandard = shared.PropertyValueDataSensitivityStandard

Equals "standard"

const PropertyValueSourceAIGroup = shared.PropertyValueSourceAIGroup

Equals "AI_GROUP"

const PropertyValueSourceAPI = shared.PropertyValueSourceAPI

Equals "API"

const PropertyValueSourceAcademy = shared.PropertyValueSourceAcademy

Equals "ACADEMY"

const PropertyValueSourceAcceptanceTest = shared.PropertyValueSourceAcceptanceTest

Equals "ACCEPTANCE_TEST"

const PropertyValueSourceActivityAutoAssociate = shared.PropertyValueSourceActivityAutoAssociate

Equals "ACTIVITY_AUTO_ASSOCIATE"

const PropertyValueSourceActivityLogRevert = shared.PropertyValueSourceActivityLogRevert

Equals "ACTIVITY_LOG_REVERT"

const PropertyValueSourceAds = shared.PropertyValueSourceAds

Equals "ADS"

const PropertyValueSourceAnalytics = shared.PropertyValueSourceAnalytics

Equals "ANALYTICS"

const PropertyValueSourceApprovals = shared.PropertyValueSourceApprovals

Equals "APPROVALS"

const PropertyValueSourceAssists = shared.PropertyValueSourceAssists

Equals "ASSISTS"

const PropertyValueSourceAssociations = shared.PropertyValueSourceAssociations

Equals "ASSOCIATIONS"

const PropertyValueSourceAutoAssociateByDomain = shared.PropertyValueSourceAutoAssociateByDomain

Equals "AUTO_ASSOCIATE_BY_DOMAIN"

const PropertyValueSourceAutomationJourney = shared.PropertyValueSourceAutomationJourney

Equals "AUTOMATION_JOURNEY"

const PropertyValueSourceAutomationPlatform = shared.PropertyValueSourceAutomationPlatform

Equals "AUTOMATION_PLATFORM"

const PropertyValueSourceAvatarsService = shared.PropertyValueSourceAvatarsService

Equals "AVATARS_SERVICE"

const PropertyValueSourceBatchUpdate = shared.PropertyValueSourceBatchUpdate

Equals "BATCH_UPDATE"

const PropertyValueSourceBccToCrm = shared.PropertyValueSourceBccToCrm

Equals "BCC_TO_CRM"

const PropertyValueSourceBehavioralEvents = shared.PropertyValueSourceBehavioralEvents

Equals "BEHAVIORAL_EVENTS"

const PropertyValueSourceBetAssignment = shared.PropertyValueSourceBetAssignment

Equals "BET_ASSIGNMENT"

const PropertyValueSourceBetCrmConnector = shared.PropertyValueSourceBetCrmConnector

Equals "BET_CRM_CONNECTOR"

const PropertyValueSourceBiden = shared.PropertyValueSourceBiden

Equals "BIDEN"

const PropertyValueSourceBilling = shared.PropertyValueSourceBilling

Equals "BILLING"

const PropertyValueSourceBot = shared.PropertyValueSourceBot

Equals "BOT"

const PropertyValueSourceCalculated = shared.PropertyValueSourceCalculated

Equals "CALCULATED"

const PropertyValueSourceCentralExchangeRates = shared.PropertyValueSourceCentralExchangeRates

Equals "CENTRAL_EXCHANGE_RATES"

const PropertyValueSourceChatspot = shared.PropertyValueSourceChatspot

Equals "CHATSPOT"

const PropertyValueSourceCloneObjects = shared.PropertyValueSourceCloneObjects

Equals "CLONE_OBJECTS"

const PropertyValueSourceCommunicator = shared.PropertyValueSourceCommunicator

Equals "COMMUNICATOR"

const PropertyValueSourceCompanies = shared.PropertyValueSourceCompanies

Equals "COMPANIES"

const PropertyValueSourceCompanyFamilies = shared.PropertyValueSourceCompanyFamilies

Equals "COMPANY_FAMILIES"

const PropertyValueSourceCompanyInsights = shared.PropertyValueSourceCompanyInsights

Equals "COMPANY_INSIGHTS"

const PropertyValueSourceConnectedAccount = shared.PropertyValueSourceConnectedAccount

Equals "CONNECTED_ACCOUNT"

const PropertyValueSourceContacts = shared.PropertyValueSourceContacts

Equals "CONTACTS"

const PropertyValueSourceContactsWeb = shared.PropertyValueSourceContactsWeb

Equals "CONTACTS_WEB"

const PropertyValueSourceContentMembership = shared.PropertyValueSourceContentMembership

Equals "CONTENT_MEMBERSHIP"

const PropertyValueSourceConversationalEnrichment = shared.PropertyValueSourceConversationalEnrichment

Equals "CONVERSATIONAL_ENRICHMENT"

const PropertyValueSourceConversations = shared.PropertyValueSourceConversations

Equals "CONVERSATIONS"

const PropertyValueSourceCrmProcessesPlatform = shared.PropertyValueSourceCrmProcessesPlatform

Equals "CRM_PROCESSES_PLATFORM"

const PropertyValueSourceCrmUi = shared.PropertyValueSourceCrmUi

Equals "CRM_UI"

const PropertyValueSourceCrmUiBulkAction = shared.PropertyValueSourceCrmUiBulkAction

Equals "CRM_UI_BULK_ACTION"

const PropertyValueSourceCustomerAgent = shared.PropertyValueSourceCustomerAgent

Equals "CUSTOMER_AGENT"

const PropertyValueSourceDataEnrichment = shared.PropertyValueSourceDataEnrichment

Equals "DATA_ENRICHMENT"

const PropertyValueSourceDataQuality = shared.PropertyValueSourceDataQuality

Equals "DATA_QUALITY"

const PropertyValueSourceDataset = shared.PropertyValueSourceDataset

Equals "DATASET"

const PropertyValueSourceDeals = shared.PropertyValueSourceDeals

Equals "DEALS"

const PropertyValueSourceDefault = shared.PropertyValueSourceDefault

Equals "DEFAULT"

const PropertyValueSourceDeleteObjects = shared.PropertyValueSourceDeleteObjects

Equals "DELETE_OBJECTS"

const PropertyValueSourceEmail = shared.PropertyValueSourceEmail

Equals "EMAIL"

const PropertyValueSourceEmailInboxImport = shared.PropertyValueSourceEmailInboxImport

Equals "EMAIL_INBOX_IMPORT"

const PropertyValueSourceEmailIntegration = shared.PropertyValueSourceEmailIntegration

Equals "EMAIL_INTEGRATION"

const PropertyValueSourceEngagements = shared.PropertyValueSourceEngagements

Equals "ENGAGEMENTS"

const PropertyValueSourceExtension = shared.PropertyValueSourceExtension

Equals "EXTENSION"

const PropertyValueSourceFileManager = shared.PropertyValueSourceFileManager

Equals "FILE_MANAGER"

const PropertyValueSourceFlywheelProductDataSync = shared.PropertyValueSourceFlywheelProductDataSync

Equals "FLYWHEEL_PRODUCT_DATA_SYNC"

const PropertyValueSourceForecasting = shared.PropertyValueSourceForecasting

Equals "FORECASTING"

const PropertyValueSourceForm = shared.PropertyValueSourceForm

Equals "FORM"

const PropertyValueSourceForwardToCrm = shared.PropertyValueSourceForwardToCrm

Equals "FORWARD_TO_CRM"

const PropertyValueSourceGmailIntegration = shared.PropertyValueSourceGmailIntegration

Equals "GMAIL_INTEGRATION"

const PropertyValueSourceGoals = shared.PropertyValueSourceGoals

Equals "GOALS"

const PropertyValueSourceHeisenberg = shared.PropertyValueSourceHeisenberg

Equals "HEISENBERG"

const PropertyValueSourceHelpDesk = shared.PropertyValueSourceHelpDesk

Equals "HELP_DESK"

const PropertyValueSourceHelpDeskAI = shared.PropertyValueSourceHelpDeskAI

Equals "HELP_DESK_AI"

const PropertyValueSourceImport = shared.PropertyValueSourceImport

Equals "IMPORT"

const PropertyValueSourceIntegration = shared.PropertyValueSourceIntegration

Equals "INTEGRATION"

const PropertyValueSourceIntegrationsPlatform = shared.PropertyValueSourceIntegrationsPlatform

Equals "INTEGRATIONS_PLATFORM"

const PropertyValueSourceIntegrationsSync = shared.PropertyValueSourceIntegrationsSync

Equals "INTEGRATIONS_SYNC"

const PropertyValueSourceIntent = shared.PropertyValueSourceIntent

Equals "INTENT"

const PropertyValueSourceInternalProcessing = shared.PropertyValueSourceInternalProcessing

Equals "INTERNAL_PROCESSING"

const PropertyValueSourceLeadin = shared.PropertyValueSourceLeadin

Equals "LEADIN"

const PropertyValueSourceLegalBasisRemediation = shared.PropertyValueSourceLegalBasisRemediation

Equals "LEGAL_BASIS_REMEDIATION"

const PropertyValueSourceMarketSourcing = shared.PropertyValueSourceMarketSourcing

Equals "MARKET_SOURCING"

const PropertyValueSourceMarketplace = shared.PropertyValueSourceMarketplace

Equals "MARKETPLACE"

const PropertyValueSourceMarkets = shared.PropertyValueSourceMarkets

Equals "MARKETS"

const PropertyValueSourceMeetings = shared.PropertyValueSourceMeetings

Equals "MEETINGS"

const PropertyValueSourceMergeCompanies = shared.PropertyValueSourceMergeCompanies

Equals "MERGE_COMPANIES"

const PropertyValueSourceMergeContacts = shared.PropertyValueSourceMergeContacts

Equals "MERGE_CONTACTS"

const PropertyValueSourceMergeObjects = shared.PropertyValueSourceMergeObjects

Equals "MERGE_OBJECTS"

const PropertyValueSourceMergeRevertObjects = shared.PropertyValueSourceMergeRevertObjects

Equals "MERGE_REVERT_OBJECTS"

const PropertyValueSourceMicroapps = shared.PropertyValueSourceMicroapps

Equals "MICROAPPS"

const PropertyValueSourceMigration = shared.PropertyValueSourceMigration

Equals "MIGRATION"

const PropertyValueSourceMobileAndroid = shared.PropertyValueSourceMobileAndroid

Equals "MOBILE_ANDROID"

const PropertyValueSourceMobileIos = shared.PropertyValueSourceMobileIos

Equals "MOBILE_IOS"

const PropertyValueSourcePayments = shared.PropertyValueSourcePayments

Equals "PAYMENTS"

const PropertyValueSourcePipelineSettings = shared.PropertyValueSourcePipelineSettings

Equals "PIPELINE_SETTINGS"

const PropertyValueSourcePlaybooks = shared.PropertyValueSourcePlaybooks

Equals "PLAYBOOKS"

const PropertyValueSourcePortalObjectSync = shared.PropertyValueSourcePortalObjectSync

Equals "PORTAL_OBJECT_SYNC"

const PropertyValueSourcePortalUserAssociator = shared.PropertyValueSourcePortalUserAssociator

Equals "PORTAL_USER_ASSOCIATOR"

const PropertyValueSourcePresentations = shared.PropertyValueSourcePresentations

Equals "PRESENTATIONS"

const PropertyValueSourcePrimaryAutomation = shared.PropertyValueSourcePrimaryAutomation

Equals "PRIMARY_AUTOMATION"

const PropertyValueSourcePropertyDefaultValue = shared.PropertyValueSourcePropertyDefaultValue

Equals "PROPERTY_DEFAULT_VALUE"

const PropertyValueSourcePropertyRestore = shared.PropertyValueSourcePropertyRestore

Equals "PROPERTY_RESTORE"

const PropertyValueSourcePropertySettings = shared.PropertyValueSourcePropertySettings

Equals "PROPERTY_SETTINGS"

const PropertyValueSourceProspectingAgent = shared.PropertyValueSourceProspectingAgent

Equals "PROSPECTING_AGENT"

const PropertyValueSourceQuotas = shared.PropertyValueSourceQuotas

Equals "QUOTAS"

const PropertyValueSourceQuotes = shared.PropertyValueSourceQuotes

Equals "QUOTES"

const PropertyValueSourceRecyclingBin = shared.PropertyValueSourceRecyclingBin

Equals "RECYCLING_BIN"

const PropertyValueSourceRestoreObjects = shared.PropertyValueSourceRestoreObjects

Equals "RESTORE_OBJECTS"

const PropertyValueSourceRevenuePlatform = shared.PropertyValueSourceRevenuePlatform

Equals "REVENUE_PLATFORM"

const PropertyValueSourceSales = shared.PropertyValueSourceSales

Equals "SALES"

const PropertyValueSourceSalesMessages = shared.PropertyValueSourceSalesMessages

Equals "SALES_MESSAGES"

const PropertyValueSourceSalesforce = shared.PropertyValueSourceSalesforce

Equals "SALESFORCE"

const PropertyValueSourceSequences = shared.PropertyValueSourceSequences

Equals "SEQUENCES"

const PropertyValueSourceSettings = shared.PropertyValueSourceSettings

Equals "SETTINGS"

const PropertyValueSourceSidekick = shared.PropertyValueSourceSidekick

Equals "SIDEKICK"

const PropertyValueSourceSignals = shared.PropertyValueSourceSignals

Equals "SIGNALS"

const PropertyValueSourceSlackIntegration = shared.PropertyValueSourceSlackIntegration

Equals "SLACK_INTEGRATION"

const PropertyValueSourceSmartDataCapture = shared.PropertyValueSourceSmartDataCapture

Equals "SMART_DATA_CAPTURE"

const PropertyValueSourceSocial = shared.PropertyValueSourceSocial

Equals "SOCIAL"

const PropertyValueSourceSuccess = shared.PropertyValueSourceSuccess

Equals "SUCCESS"

const PropertyValueSourceTally = shared.PropertyValueSourceTally

Equals "TALLY"

const PropertyValueSourceTask = shared.PropertyValueSourceTask

Equals "TASK"

const PropertyValueSourceUnknown = shared.PropertyValueSourceUnknown

Equals "UNKNOWN"

const PropertyValueSourceWalIncremental = shared.PropertyValueSourceWalIncremental

Equals "WAL_INCREMENTAL"

const PropertyValueSourceWorkUi = shared.PropertyValueSourceWorkUi

Equals "WORK_UI"

const PropertyValueSourceWorkflowContactDeleteAction = shared.PropertyValueSourceWorkflowContactDeleteAction

Equals "WORKFLOW_CONTACT_DELETE_ACTION"

const PropertyValueSourceWorkflows = shared.PropertyValueSourceWorkflows

Equals "WORKFLOWS"

Variables

This section is empty.

Functions

func Bool

func Bool(b bool) param.Opt[bool]

func BoolPtr

func BoolPtr(v bool) *bool

func DefaultClientOptions

func DefaultClientOptions() []option.RequestOption

DefaultClientOptions read from the environment (HUBSPOT_BASE_URL). This should be used to initialize new clients.

func File

func File(rdr io.Reader, filename string, contentType string) file

func Float

func Float(f float64) param.Opt[float64]

func FloatPtr

func FloatPtr(v float64) *float64

func Int

func Int(i int64) param.Opt[int64]

func IntPtr

func IntPtr(v int64) *int64

func Opt

func Opt[T comparable](v T) param.Opt[T]

func Ptr

func Ptr[T any](v T) *T

func String

func String(s string) param.Opt[string]

func StringPtr

func StringPtr(v string) *string

func Time

func Time(t time.Time) param.Opt[time.Time]

func TimePtr

func TimePtr(v time.Time) *time.Time

Types

type AbTestCreateRequestVNextParam

type AbTestCreateRequestVNextParam = shared.AbTestCreateRequestVNextParam

This is an alias to an internal type.

type ActionResponse

type ActionResponse = shared.ActionResponse

This is an alias to an internal type.

type ActionResponseStatus

type ActionResponseStatus = shared.ActionResponseStatus

The current status of the action, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.

This is an alias to an internal type.

type AssociationDefinition

type AssociationDefinition = shared.AssociationDefinition

The definition of an association

This is an alias to an internal type.

type AssociationDefinitionEggParam

type AssociationDefinitionEggParam = shared.AssociationDefinitionEggParam

This is an alias to an internal type.

type AssociationSpec

type AssociationSpec = shared.AssociationSpec

Defines the type, direction, and details of the relationship between two CRM objects.

This is an alias to an internal type.

type AssociationSpecAssociationCategory

type AssociationSpecAssociationCategory = shared.AssociationSpecAssociationCategory

The category of the association, such as "HUBSPOT_DEFINED".

This is an alias to an internal type.

type AssociationSpecParam

type AssociationSpecParam = shared.AssociationSpecParam

Defines the type, direction, and details of the relationship between two CRM objects.

This is an alias to an internal type.

type AutomationActionsOption

type AutomationActionsOption = shared.AutomationActionsOption

A HubSpot property option

This is an alias to an internal type.

type AutomationActionsOptionParam

type AutomationActionsOptionParam = shared.AutomationActionsOptionParam

A HubSpot property option

This is an alias to an internal type.

type BatchInputPropertyCreateParam

type BatchInputPropertyCreateParam = shared.BatchInputPropertyCreateParam

This is an alias to an internal type.

type BatchInputPropertyNameParam

type BatchInputPropertyNameParam = shared.BatchInputPropertyNameParam

This is an alias to an internal type.

type BatchInputPublicObjectIDParam

type BatchInputPublicObjectIDParam = shared.BatchInputPublicObjectIDParam

This is an alias to an internal type.

type BatchInputStringParam

type BatchInputStringParam = shared.BatchInputStringParam

This is an alias to an internal type.

type BatchReadInputPropertyNameDataSensitivity

type BatchReadInputPropertyNameDataSensitivity = shared.BatchReadInputPropertyNameDataSensitivity

This is an alias to an internal type.

type BatchReadInputPropertyNameParam

type BatchReadInputPropertyNameParam = shared.BatchReadInputPropertyNameParam

This is an alias to an internal type.

type Client

type Client struct {
	Account                  account.AccountService
	Auth                     auth.AuthService
	Automation               automation.AutomationService
	BusinessUnits            business_units.BusinessUnitService
	Cms                      cms.CmService
	CommunicationPreferences communication_preferences.CommunicationPreferenceService
	Conversations            conversations.ConversationService
	Crm                      crm.CrmService
	Events                   events.EventService
	Files                    files.FileService
	Marketing                marketing.MarketingService
	Meta                     meta.MetaService
	Scheduler                scheduler.SchedulerService
	Settings                 settings.SettingService
	Webhooks                 webhooks.WebhookService
	// contains filtered or unexported fields
}

Client creates a struct with services and top level methods that help with interacting with the hubspot API. You should not instantiate this client directly, and instead use the NewClient method instead.

func NewClient

func NewClient(opts ...option.RequestOption) (r Client)

NewClient generates a new client with the default option read from the environment (HUBSPOT_BASE_URL). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.

func (*Client) Delete

func (r *Client) Delete(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Execute

func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, opts ...option.RequestOption) error

Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.

If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.

The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned [url.Values] will be used as query strings to the url.

If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.

Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.

The response body will be deserialized into the res variable, depending on its type:

  • A pointer to a *http.Response is populated by the raw response.
  • A pointer to a byte array will be populated with the contents of the request body.
  • A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
  • A nil value will not read the response body.

For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.

func (*Client) Get

func (r *Client) Get(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Patch

func (r *Client) Patch(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Post

func (r *Client) Post(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Post makes a POST request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

func (*Client) Put

func (r *Client) Put(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error

Put makes a PUT request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.

type CollectionResponsePropertyGroupNoPaging

type CollectionResponsePropertyGroupNoPaging = shared.CollectionResponsePropertyGroupNoPaging

This is an alias to an internal type.

type Error

type Error = apierror.Error

type ErrorData

type ErrorData = shared.ErrorData

This is an alias to an internal type.

type ErrorDetail

type ErrorDetail = shared.ErrorDetail

This is an alias to an internal type.

type ForwardPaging

type ForwardPaging = shared.ForwardPaging

This is an alias to an internal type.

type NextPage

type NextPage = shared.NextPage

Specifies the paging information needed to retrieve the next set of results in a paginated API response

This is an alias to an internal type.

type ObjectTypeDefinition

type ObjectTypeDefinition = shared.ObjectTypeDefinition

This is an alias to an internal type.

type ObjectTypeDefinitionLabels

type ObjectTypeDefinitionLabels = shared.ObjectTypeDefinitionLabels

This is an alias to an internal type.

type ObjectTypeDefinitionLabelsParam

type ObjectTypeDefinitionLabelsParam = shared.ObjectTypeDefinitionLabelsParam

This is an alias to an internal type.

type ObjectTypeDefinitionPatchParam

type ObjectTypeDefinitionPatchParam = shared.ObjectTypeDefinitionPatchParam

This is an alias to an internal type.

type Option

type Option = shared.Option

A HubSpot property option

This is an alias to an internal type.

type OptionInputParam

type OptionInputParam = shared.OptionInputParam

This is an alias to an internal type.

type Paging

type Paging = shared.Paging

This is an alias to an internal type.

type PreviousPage

type PreviousPage = shared.PreviousPage

specifies the paging information needed to retrieve the previous set of results in a paginated API response

This is an alias to an internal type.

type Property

type Property = shared.Property

A HubSpot property

This is an alias to an internal type.

type PropertyCreateDataSensitivity

type PropertyCreateDataSensitivity = shared.PropertyCreateDataSensitivity

This is an alias to an internal type.

type PropertyCreateFieldType

type PropertyCreateFieldType = shared.PropertyCreateFieldType

This is an alias to an internal type.

type PropertyCreateNumberDisplayHint

type PropertyCreateNumberDisplayHint = shared.PropertyCreateNumberDisplayHint

This is an alias to an internal type.

type PropertyCreateParam

type PropertyCreateParam = shared.PropertyCreateParam

This is an alias to an internal type.

type PropertyCreateType

type PropertyCreateType = shared.PropertyCreateType

This is an alias to an internal type.

type PropertyDataSensitivity

type PropertyDataSensitivity = shared.PropertyDataSensitivity

Indicates the sensitivity level of the property, such as "non_sensitive", "sensitive", or "highly_sensitive".

This is an alias to an internal type.

type PropertyDateDisplayHint

type PropertyDateDisplayHint = shared.PropertyDateDisplayHint

Controls how date properties are displayed in the HubSpot UI, with options such as 'absolute', 'absolute_with_relative', 'time_since', and 'time_until'.

This is an alias to an internal type.

type PropertyGroup

type PropertyGroup = shared.PropertyGroup

This is an alias to an internal type.

type PropertyGroupCreateParam

type PropertyGroupCreateParam = shared.PropertyGroupCreateParam

This is an alias to an internal type.

type PropertyGroupUpdateParam

type PropertyGroupUpdateParam = shared.PropertyGroupUpdateParam

This is an alias to an internal type.

type PropertyModificationMetadata

type PropertyModificationMetadata = shared.PropertyModificationMetadata

This is an alias to an internal type.

type PropertyNameParam

type PropertyNameParam = shared.PropertyNameParam

This is an alias to an internal type.

type PropertyNumberDisplayHint

type PropertyNumberDisplayHint = shared.PropertyNumberDisplayHint

Hint for how a number property is displayed and validated in HubSpot's UI. Can be: "unformatted", "formatted", "currency", "percentage", "duration", or "probability".

This is an alias to an internal type.

type PropertyValue

type PropertyValue = shared.PropertyValue

Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.

This is an alias to an internal type.

type PropertyValueDataSensitivity

type PropertyValueDataSensitivity = shared.PropertyValueDataSensitivity

The sensitivity level of the property, such as "non_sensitive", "sensitive", and "highly_sensitive".

This is an alias to an internal type.

type PropertyValueParam

type PropertyValueParam = shared.PropertyValueParam

Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.

This is an alias to an internal type.

type PropertyValueSource

type PropertyValueSource = shared.PropertyValueSource

The origin of the property value, such as "IMPORT" or "API".

This is an alias to an internal type.

type PublicObjectID

type PublicObjectID = shared.PublicObjectID

Contains the Id of a Public Object

This is an alias to an internal type.

type PublicObjectIDParam

type PublicObjectIDParam = shared.PublicObjectIDParam

Contains the Id of a Public Object

This is an alias to an internal type.

type StandardError

type StandardError = shared.StandardError

Ye olde error

This is an alias to an internal type.

type TaskLocator

type TaskLocator = shared.TaskLocator

This is an alias to an internal type.

type VersionUser

type VersionUser = shared.VersionUser

This is an alias to an internal type.

Directories

Path Synopsis
encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
Package json implements encoding and decoding of JSON as defined in RFC 7159.
encoding/json/shims
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
packages

Jump to