Documentation
¶
Index ¶
- Constants
- func Bool(b bool) param.Opt[bool]
- func BoolPtr(v bool) *bool
- func DefaultClientOptions() []option.RequestOption
- func File(rdr io.Reader, filename string, contentType string) file
- func Float(f float64) param.Opt[float64]
- func FloatPtr(v float64) *float64
- func Int(i int64) param.Opt[int64]
- func IntPtr(v int64) *int64
- func Opt[T comparable](v T) param.Opt[T]
- func Ptr[T any](v T) *T
- func String(s string) param.Opt[string]
- func StringPtr(v string) *string
- func Time(t time.Time) param.Opt[time.Time]
- func TimePtr(v time.Time) *time.Time
- type AbTestCreateRequestVNextParam
- type ActionResponse
- type ActionResponseStatus
- type AssociationDefinition
- type AssociationDefinitionEggParam
- type AssociationSpec
- type AssociationSpecAssociationCategory
- type AssociationSpecParam
- type AutomationActionsOption
- type AutomationActionsOptionParam
- type BatchInputPropertyCreateParam
- type BatchInputPropertyNameParam
- type BatchInputPublicObjectIDParam
- type BatchInputStringParam
- type BatchReadInputPropertyNameDataSensitivity
- type BatchReadInputPropertyNameParam
- type Client
- func (r *Client) Delete(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, ...) error
- func (r *Client) Get(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Patch(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Post(ctx context.Context, path string, params any, res any, ...) error
- func (r *Client) Put(ctx context.Context, path string, params any, res any, ...) error
- type CollectionResponsePropertyGroupNoPaging
- type Error
- type ErrorData
- type ErrorDetail
- type ForwardPaging
- type NextPage
- type ObjectTypeDefinition
- type ObjectTypeDefinitionLabels
- type ObjectTypeDefinitionLabelsParam
- type ObjectTypeDefinitionPatchParam
- type Option
- type OptionInputParam
- type Paging
- type PreviousPage
- type Property
- type PropertyCreateDataSensitivity
- type PropertyCreateFieldType
- type PropertyCreateNumberDisplayHint
- type PropertyCreateParam
- type PropertyCreateType
- type PropertyDataSensitivity
- type PropertyDateDisplayHint
- type PropertyGroup
- type PropertyGroupCreateParam
- type PropertyGroupUpdateParam
- type PropertyModificationMetadata
- type PropertyNameParam
- type PropertyNumberDisplayHint
- type PropertyValue
- type PropertyValueDataSensitivity
- type PropertyValueParam
- type PropertyValueSource
- type PublicObjectID
- type PublicObjectIDParam
- type StandardError
- type TaskLocator
- type VersionUser
Constants ¶
const ActionResponseStatusCanceled = shared.ActionResponseStatusCanceled
Equals "CANCELED"
const ActionResponseStatusComplete = shared.ActionResponseStatusComplete
Equals "COMPLETE"
const ActionResponseStatusPending = shared.ActionResponseStatusPending
Equals "PENDING"
const ActionResponseStatusProcessing = shared.ActionResponseStatusProcessing
Equals "PROCESSING"
const AssociationSpecAssociationCategoryHubSpotDefined = shared.AssociationSpecAssociationCategoryHubSpotDefined
Equals "HUBSPOT_DEFINED"
const AssociationSpecAssociationCategoryIntegratorDefined = shared.AssociationSpecAssociationCategoryIntegratorDefined
Equals "INTEGRATOR_DEFINED"
const AssociationSpecAssociationCategoryUserDefined = shared.AssociationSpecAssociationCategoryUserDefined
Equals "USER_DEFINED"
const AssociationSpecAssociationCategoryWork = shared.AssociationSpecAssociationCategoryWork
Equals "WORK"
const BatchReadInputPropertyNameDataSensitivityHighlySensitive = shared.BatchReadInputPropertyNameDataSensitivityHighlySensitive
Equals "highly_sensitive"
const BatchReadInputPropertyNameDataSensitivityNonSensitive = shared.BatchReadInputPropertyNameDataSensitivityNonSensitive
Equals "non_sensitive"
const BatchReadInputPropertyNameDataSensitivitySensitive = shared.BatchReadInputPropertyNameDataSensitivitySensitive
Equals "sensitive"
const PropertyCreateDataSensitivityHighlySensitive = shared.PropertyCreateDataSensitivityHighlySensitive
Equals "highly_sensitive"
const PropertyCreateDataSensitivityNonSensitive = shared.PropertyCreateDataSensitivityNonSensitive
Equals "non_sensitive"
const PropertyCreateDataSensitivitySensitive = shared.PropertyCreateDataSensitivitySensitive
Equals "sensitive"
const PropertyCreateFieldTypeBooleancheckbox = shared.PropertyCreateFieldTypeBooleancheckbox
Equals "booleancheckbox"
const PropertyCreateFieldTypeCalculationEquation = shared.PropertyCreateFieldTypeCalculationEquation
Equals "calculation_equation"
const PropertyCreateFieldTypeCheckbox = shared.PropertyCreateFieldTypeCheckbox
Equals "checkbox"
const PropertyCreateFieldTypeDate = shared.PropertyCreateFieldTypeDate
Equals "date"
const PropertyCreateFieldTypeFile = shared.PropertyCreateFieldTypeFile
Equals "file"
const PropertyCreateFieldTypeHTML = shared.PropertyCreateFieldTypeHTML
Equals "html"
const PropertyCreateFieldTypeNumber = shared.PropertyCreateFieldTypeNumber
Equals "number"
const PropertyCreateFieldTypePhonenumber = shared.PropertyCreateFieldTypePhonenumber
Equals "phonenumber"
const PropertyCreateFieldTypeRadio = shared.PropertyCreateFieldTypeRadio
Equals "radio"
const PropertyCreateFieldTypeSelect = shared.PropertyCreateFieldTypeSelect
Equals "select"
const PropertyCreateFieldTypeText = shared.PropertyCreateFieldTypeText
Equals "text"
const PropertyCreateFieldTypeTextarea = shared.PropertyCreateFieldTypeTextarea
Equals "textarea"
const PropertyCreateNumberDisplayHintCurrency = shared.PropertyCreateNumberDisplayHintCurrency
Equals "currency"
const PropertyCreateNumberDisplayHintDuration = shared.PropertyCreateNumberDisplayHintDuration
Equals "duration"
const PropertyCreateNumberDisplayHintFormatted = shared.PropertyCreateNumberDisplayHintFormatted
Equals "formatted"
const PropertyCreateNumberDisplayHintPercentage = shared.PropertyCreateNumberDisplayHintPercentage
Equals "percentage"
const PropertyCreateNumberDisplayHintProbability = shared.PropertyCreateNumberDisplayHintProbability
Equals "probability"
const PropertyCreateNumberDisplayHintUnformatted = shared.PropertyCreateNumberDisplayHintUnformatted
Equals "unformatted"
const PropertyCreateTypeBool = shared.PropertyCreateTypeBool
Equals "bool"
const PropertyCreateTypeDate = shared.PropertyCreateTypeDate
Equals "date"
const PropertyCreateTypeDatetime = shared.PropertyCreateTypeDatetime
Equals "datetime"
const PropertyCreateTypeEnumeration = shared.PropertyCreateTypeEnumeration
Equals "enumeration"
const PropertyCreateTypeNumber = shared.PropertyCreateTypeNumber
Equals "number"
const PropertyCreateTypePhoneNumber = shared.PropertyCreateTypePhoneNumber
Equals "phone_number"
const PropertyCreateTypeString = shared.PropertyCreateTypeString
Equals "string"
const PropertyDataSensitivityHighlySensitive = shared.PropertyDataSensitivityHighlySensitive
Equals "highly_sensitive"
const PropertyDataSensitivityNonSensitive = shared.PropertyDataSensitivityNonSensitive
Equals "non_sensitive"
const PropertyDataSensitivitySensitive = shared.PropertyDataSensitivitySensitive
Equals "sensitive"
const PropertyDateDisplayHintAbsolute = shared.PropertyDateDisplayHintAbsolute
Equals "absolute"
const PropertyDateDisplayHintAbsoluteWithRelative = shared.PropertyDateDisplayHintAbsoluteWithRelative
Equals "absolute_with_relative"
const PropertyDateDisplayHintTimeSince = shared.PropertyDateDisplayHintTimeSince
Equals "time_since"
const PropertyDateDisplayHintTimeUntil = shared.PropertyDateDisplayHintTimeUntil
Equals "time_until"
const PropertyNumberDisplayHintCurrency = shared.PropertyNumberDisplayHintCurrency
Equals "currency"
const PropertyNumberDisplayHintDuration = shared.PropertyNumberDisplayHintDuration
Equals "duration"
const PropertyNumberDisplayHintFormatted = shared.PropertyNumberDisplayHintFormatted
Equals "formatted"
const PropertyNumberDisplayHintPercentage = shared.PropertyNumberDisplayHintPercentage
Equals "percentage"
const PropertyNumberDisplayHintProbability = shared.PropertyNumberDisplayHintProbability
Equals "probability"
const PropertyNumberDisplayHintUnformatted = shared.PropertyNumberDisplayHintUnformatted
Equals "unformatted"
const PropertyValueDataSensitivityHigh = shared.PropertyValueDataSensitivityHigh
Equals "high"
const PropertyValueDataSensitivityNone = shared.PropertyValueDataSensitivityNone
Equals "none"
const PropertyValueDataSensitivityStandard = shared.PropertyValueDataSensitivityStandard
Equals "standard"
const PropertyValueSourceAIGroup = shared.PropertyValueSourceAIGroup
Equals "AI_GROUP"
const PropertyValueSourceAPI = shared.PropertyValueSourceAPI
Equals "API"
const PropertyValueSourceAcademy = shared.PropertyValueSourceAcademy
Equals "ACADEMY"
const PropertyValueSourceAcceptanceTest = shared.PropertyValueSourceAcceptanceTest
Equals "ACCEPTANCE_TEST"
const PropertyValueSourceActivityAutoAssociate = shared.PropertyValueSourceActivityAutoAssociate
Equals "ACTIVITY_AUTO_ASSOCIATE"
const PropertyValueSourceActivityLogRevert = shared.PropertyValueSourceActivityLogRevert
Equals "ACTIVITY_LOG_REVERT"
const PropertyValueSourceAds = shared.PropertyValueSourceAds
Equals "ADS"
const PropertyValueSourceAnalytics = shared.PropertyValueSourceAnalytics
Equals "ANALYTICS"
const PropertyValueSourceApprovals = shared.PropertyValueSourceApprovals
Equals "APPROVALS"
const PropertyValueSourceAssists = shared.PropertyValueSourceAssists
Equals "ASSISTS"
const PropertyValueSourceAssociations = shared.PropertyValueSourceAssociations
Equals "ASSOCIATIONS"
const PropertyValueSourceAutoAssociateByDomain = shared.PropertyValueSourceAutoAssociateByDomain
Equals "AUTO_ASSOCIATE_BY_DOMAIN"
const PropertyValueSourceAutomationJourney = shared.PropertyValueSourceAutomationJourney
Equals "AUTOMATION_JOURNEY"
const PropertyValueSourceAutomationPlatform = shared.PropertyValueSourceAutomationPlatform
Equals "AUTOMATION_PLATFORM"
const PropertyValueSourceAvatarsService = shared.PropertyValueSourceAvatarsService
Equals "AVATARS_SERVICE"
const PropertyValueSourceBatchUpdate = shared.PropertyValueSourceBatchUpdate
Equals "BATCH_UPDATE"
const PropertyValueSourceBccToCrm = shared.PropertyValueSourceBccToCrm
Equals "BCC_TO_CRM"
const PropertyValueSourceBehavioralEvents = shared.PropertyValueSourceBehavioralEvents
Equals "BEHAVIORAL_EVENTS"
const PropertyValueSourceBetAssignment = shared.PropertyValueSourceBetAssignment
Equals "BET_ASSIGNMENT"
const PropertyValueSourceBetCrmConnector = shared.PropertyValueSourceBetCrmConnector
Equals "BET_CRM_CONNECTOR"
const PropertyValueSourceBiden = shared.PropertyValueSourceBiden
Equals "BIDEN"
const PropertyValueSourceBilling = shared.PropertyValueSourceBilling
Equals "BILLING"
const PropertyValueSourceBot = shared.PropertyValueSourceBot
Equals "BOT"
const PropertyValueSourceCalculated = shared.PropertyValueSourceCalculated
Equals "CALCULATED"
const PropertyValueSourceCentralExchangeRates = shared.PropertyValueSourceCentralExchangeRates
Equals "CENTRAL_EXCHANGE_RATES"
const PropertyValueSourceChatspot = shared.PropertyValueSourceChatspot
Equals "CHATSPOT"
const PropertyValueSourceCloneObjects = shared.PropertyValueSourceCloneObjects
Equals "CLONE_OBJECTS"
const PropertyValueSourceCommunicator = shared.PropertyValueSourceCommunicator
Equals "COMMUNICATOR"
const PropertyValueSourceCompanies = shared.PropertyValueSourceCompanies
Equals "COMPANIES"
const PropertyValueSourceCompanyFamilies = shared.PropertyValueSourceCompanyFamilies
Equals "COMPANY_FAMILIES"
const PropertyValueSourceCompanyInsights = shared.PropertyValueSourceCompanyInsights
Equals "COMPANY_INSIGHTS"
const PropertyValueSourceConnectedAccount = shared.PropertyValueSourceConnectedAccount
Equals "CONNECTED_ACCOUNT"
const PropertyValueSourceContacts = shared.PropertyValueSourceContacts
Equals "CONTACTS"
const PropertyValueSourceContactsWeb = shared.PropertyValueSourceContactsWeb
Equals "CONTACTS_WEB"
const PropertyValueSourceContentMembership = shared.PropertyValueSourceContentMembership
Equals "CONTENT_MEMBERSHIP"
const PropertyValueSourceConversationalEnrichment = shared.PropertyValueSourceConversationalEnrichment
Equals "CONVERSATIONAL_ENRICHMENT"
const PropertyValueSourceConversations = shared.PropertyValueSourceConversations
Equals "CONVERSATIONS"
const PropertyValueSourceCrmProcessesPlatform = shared.PropertyValueSourceCrmProcessesPlatform
Equals "CRM_PROCESSES_PLATFORM"
const PropertyValueSourceCrmUi = shared.PropertyValueSourceCrmUi
Equals "CRM_UI"
const PropertyValueSourceCrmUiBulkAction = shared.PropertyValueSourceCrmUiBulkAction
Equals "CRM_UI_BULK_ACTION"
const PropertyValueSourceCustomerAgent = shared.PropertyValueSourceCustomerAgent
Equals "CUSTOMER_AGENT"
const PropertyValueSourceDataEnrichment = shared.PropertyValueSourceDataEnrichment
Equals "DATA_ENRICHMENT"
const PropertyValueSourceDataQuality = shared.PropertyValueSourceDataQuality
Equals "DATA_QUALITY"
const PropertyValueSourceDataset = shared.PropertyValueSourceDataset
Equals "DATASET"
const PropertyValueSourceDeals = shared.PropertyValueSourceDeals
Equals "DEALS"
const PropertyValueSourceDefault = shared.PropertyValueSourceDefault
Equals "DEFAULT"
const PropertyValueSourceDeleteObjects = shared.PropertyValueSourceDeleteObjects
Equals "DELETE_OBJECTS"
const PropertyValueSourceEmail = shared.PropertyValueSourceEmail
Equals "EMAIL"
const PropertyValueSourceEmailInboxImport = shared.PropertyValueSourceEmailInboxImport
Equals "EMAIL_INBOX_IMPORT"
const PropertyValueSourceEmailIntegration = shared.PropertyValueSourceEmailIntegration
Equals "EMAIL_INTEGRATION"
const PropertyValueSourceEngagements = shared.PropertyValueSourceEngagements
Equals "ENGAGEMENTS"
const PropertyValueSourceExtension = shared.PropertyValueSourceExtension
Equals "EXTENSION"
const PropertyValueSourceFileManager = shared.PropertyValueSourceFileManager
Equals "FILE_MANAGER"
const PropertyValueSourceFlywheelProductDataSync = shared.PropertyValueSourceFlywheelProductDataSync
Equals "FLYWHEEL_PRODUCT_DATA_SYNC"
const PropertyValueSourceForecasting = shared.PropertyValueSourceForecasting
Equals "FORECASTING"
const PropertyValueSourceForm = shared.PropertyValueSourceForm
Equals "FORM"
const PropertyValueSourceForwardToCrm = shared.PropertyValueSourceForwardToCrm
Equals "FORWARD_TO_CRM"
const PropertyValueSourceGmailIntegration = shared.PropertyValueSourceGmailIntegration
Equals "GMAIL_INTEGRATION"
const PropertyValueSourceGoals = shared.PropertyValueSourceGoals
Equals "GOALS"
const PropertyValueSourceHeisenberg = shared.PropertyValueSourceHeisenberg
Equals "HEISENBERG"
const PropertyValueSourceHelpDesk = shared.PropertyValueSourceHelpDesk
Equals "HELP_DESK"
const PropertyValueSourceHelpDeskAI = shared.PropertyValueSourceHelpDeskAI
Equals "HELP_DESK_AI"
const PropertyValueSourceImport = shared.PropertyValueSourceImport
Equals "IMPORT"
const PropertyValueSourceIntegration = shared.PropertyValueSourceIntegration
Equals "INTEGRATION"
const PropertyValueSourceIntegrationsPlatform = shared.PropertyValueSourceIntegrationsPlatform
Equals "INTEGRATIONS_PLATFORM"
const PropertyValueSourceIntegrationsSync = shared.PropertyValueSourceIntegrationsSync
Equals "INTEGRATIONS_SYNC"
const PropertyValueSourceIntent = shared.PropertyValueSourceIntent
Equals "INTENT"
const PropertyValueSourceInternalProcessing = shared.PropertyValueSourceInternalProcessing
Equals "INTERNAL_PROCESSING"
const PropertyValueSourceLeadin = shared.PropertyValueSourceLeadin
Equals "LEADIN"
const PropertyValueSourceLegalBasisRemediation = shared.PropertyValueSourceLegalBasisRemediation
Equals "LEGAL_BASIS_REMEDIATION"
const PropertyValueSourceMarketSourcing = shared.PropertyValueSourceMarketSourcing
Equals "MARKET_SOURCING"
const PropertyValueSourceMarketplace = shared.PropertyValueSourceMarketplace
Equals "MARKETPLACE"
const PropertyValueSourceMarkets = shared.PropertyValueSourceMarkets
Equals "MARKETS"
const PropertyValueSourceMeetings = shared.PropertyValueSourceMeetings
Equals "MEETINGS"
const PropertyValueSourceMergeCompanies = shared.PropertyValueSourceMergeCompanies
Equals "MERGE_COMPANIES"
const PropertyValueSourceMergeContacts = shared.PropertyValueSourceMergeContacts
Equals "MERGE_CONTACTS"
const PropertyValueSourceMergeObjects = shared.PropertyValueSourceMergeObjects
Equals "MERGE_OBJECTS"
const PropertyValueSourceMergeRevertObjects = shared.PropertyValueSourceMergeRevertObjects
Equals "MERGE_REVERT_OBJECTS"
const PropertyValueSourceMicroapps = shared.PropertyValueSourceMicroapps
Equals "MICROAPPS"
const PropertyValueSourceMigration = shared.PropertyValueSourceMigration
Equals "MIGRATION"
const PropertyValueSourceMobileAndroid = shared.PropertyValueSourceMobileAndroid
Equals "MOBILE_ANDROID"
const PropertyValueSourceMobileIos = shared.PropertyValueSourceMobileIos
Equals "MOBILE_IOS"
const PropertyValueSourcePayments = shared.PropertyValueSourcePayments
Equals "PAYMENTS"
const PropertyValueSourcePipelineSettings = shared.PropertyValueSourcePipelineSettings
Equals "PIPELINE_SETTINGS"
const PropertyValueSourcePlaybooks = shared.PropertyValueSourcePlaybooks
Equals "PLAYBOOKS"
const PropertyValueSourcePortalObjectSync = shared.PropertyValueSourcePortalObjectSync
Equals "PORTAL_OBJECT_SYNC"
const PropertyValueSourcePortalUserAssociator = shared.PropertyValueSourcePortalUserAssociator
Equals "PORTAL_USER_ASSOCIATOR"
const PropertyValueSourcePresentations = shared.PropertyValueSourcePresentations
Equals "PRESENTATIONS"
const PropertyValueSourcePrimaryAutomation = shared.PropertyValueSourcePrimaryAutomation
Equals "PRIMARY_AUTOMATION"
const PropertyValueSourcePropertyDefaultValue = shared.PropertyValueSourcePropertyDefaultValue
Equals "PROPERTY_DEFAULT_VALUE"
const PropertyValueSourcePropertyRestore = shared.PropertyValueSourcePropertyRestore
Equals "PROPERTY_RESTORE"
const PropertyValueSourcePropertySettings = shared.PropertyValueSourcePropertySettings
Equals "PROPERTY_SETTINGS"
const PropertyValueSourceProspectingAgent = shared.PropertyValueSourceProspectingAgent
Equals "PROSPECTING_AGENT"
const PropertyValueSourceQuotas = shared.PropertyValueSourceQuotas
Equals "QUOTAS"
const PropertyValueSourceQuotes = shared.PropertyValueSourceQuotes
Equals "QUOTES"
const PropertyValueSourceRecyclingBin = shared.PropertyValueSourceRecyclingBin
Equals "RECYCLING_BIN"
const PropertyValueSourceRestoreObjects = shared.PropertyValueSourceRestoreObjects
Equals "RESTORE_OBJECTS"
const PropertyValueSourceRevenuePlatform = shared.PropertyValueSourceRevenuePlatform
Equals "REVENUE_PLATFORM"
const PropertyValueSourceSales = shared.PropertyValueSourceSales
Equals "SALES"
const PropertyValueSourceSalesMessages = shared.PropertyValueSourceSalesMessages
Equals "SALES_MESSAGES"
const PropertyValueSourceSalesforce = shared.PropertyValueSourceSalesforce
Equals "SALESFORCE"
const PropertyValueSourceSequences = shared.PropertyValueSourceSequences
Equals "SEQUENCES"
const PropertyValueSourceSettings = shared.PropertyValueSourceSettings
Equals "SETTINGS"
const PropertyValueSourceSidekick = shared.PropertyValueSourceSidekick
Equals "SIDEKICK"
const PropertyValueSourceSignals = shared.PropertyValueSourceSignals
Equals "SIGNALS"
const PropertyValueSourceSlackIntegration = shared.PropertyValueSourceSlackIntegration
Equals "SLACK_INTEGRATION"
const PropertyValueSourceSmartDataCapture = shared.PropertyValueSourceSmartDataCapture
Equals "SMART_DATA_CAPTURE"
const PropertyValueSourceSocial = shared.PropertyValueSourceSocial
Equals "SOCIAL"
const PropertyValueSourceSuccess = shared.PropertyValueSourceSuccess
Equals "SUCCESS"
const PropertyValueSourceTally = shared.PropertyValueSourceTally
Equals "TALLY"
const PropertyValueSourceTask = shared.PropertyValueSourceTask
Equals "TASK"
const PropertyValueSourceUnknown = shared.PropertyValueSourceUnknown
Equals "UNKNOWN"
const PropertyValueSourceWalIncremental = shared.PropertyValueSourceWalIncremental
Equals "WAL_INCREMENTAL"
const PropertyValueSourceWorkUi = shared.PropertyValueSourceWorkUi
Equals "WORK_UI"
const PropertyValueSourceWorkflowContactDeleteAction = shared.PropertyValueSourceWorkflowContactDeleteAction
Equals "WORKFLOW_CONTACT_DELETE_ACTION"
const PropertyValueSourceWorkflows = shared.PropertyValueSourceWorkflows
Equals "WORKFLOWS"
Variables ¶
This section is empty.
Functions ¶
func DefaultClientOptions ¶
func DefaultClientOptions() []option.RequestOption
DefaultClientOptions read from the environment (HUBSPOT_BASE_URL). This should be used to initialize new clients.
func Opt ¶
func Opt[T comparable](v T) param.Opt[T]
Types ¶
type AbTestCreateRequestVNextParam ¶
type AbTestCreateRequestVNextParam = shared.AbTestCreateRequestVNextParam
This is an alias to an internal type.
type ActionResponse ¶
type ActionResponse = shared.ActionResponse
This is an alias to an internal type.
type ActionResponseStatus ¶
type ActionResponseStatus = shared.ActionResponseStatus
The current status of the action, with possible values: CANCELED, COMPLETE, PENDING, PROCESSING.
This is an alias to an internal type.
type AssociationDefinition ¶
type AssociationDefinition = shared.AssociationDefinition
The definition of an association
This is an alias to an internal type.
type AssociationDefinitionEggParam ¶
type AssociationDefinitionEggParam = shared.AssociationDefinitionEggParam
This is an alias to an internal type.
type AssociationSpec ¶
type AssociationSpec = shared.AssociationSpec
Defines the type, direction, and details of the relationship between two CRM objects.
This is an alias to an internal type.
type AssociationSpecAssociationCategory ¶
type AssociationSpecAssociationCategory = shared.AssociationSpecAssociationCategory
The category of the association, such as "HUBSPOT_DEFINED".
This is an alias to an internal type.
type AssociationSpecParam ¶
type AssociationSpecParam = shared.AssociationSpecParam
Defines the type, direction, and details of the relationship between two CRM objects.
This is an alias to an internal type.
type AutomationActionsOption ¶
type AutomationActionsOption = shared.AutomationActionsOption
A HubSpot property option
This is an alias to an internal type.
type AutomationActionsOptionParam ¶
type AutomationActionsOptionParam = shared.AutomationActionsOptionParam
A HubSpot property option
This is an alias to an internal type.
type BatchInputPropertyCreateParam ¶
type BatchInputPropertyCreateParam = shared.BatchInputPropertyCreateParam
This is an alias to an internal type.
type BatchInputPropertyNameParam ¶
type BatchInputPropertyNameParam = shared.BatchInputPropertyNameParam
This is an alias to an internal type.
type BatchInputPublicObjectIDParam ¶
type BatchInputPublicObjectIDParam = shared.BatchInputPublicObjectIDParam
This is an alias to an internal type.
type BatchInputStringParam ¶
type BatchInputStringParam = shared.BatchInputStringParam
This is an alias to an internal type.
type BatchReadInputPropertyNameDataSensitivity ¶
type BatchReadInputPropertyNameDataSensitivity = shared.BatchReadInputPropertyNameDataSensitivity
This is an alias to an internal type.
type BatchReadInputPropertyNameParam ¶
type BatchReadInputPropertyNameParam = shared.BatchReadInputPropertyNameParam
This is an alias to an internal type.
type Client ¶
type Client struct {
Account account.AccountService
Auth auth.AuthService
Automation automation.AutomationService
BusinessUnits business_units.BusinessUnitService
Cms cms.CmService
CommunicationPreferences communication_preferences.CommunicationPreferenceService
Conversations conversations.ConversationService
Crm crm.CrmService
Events events.EventService
Files files.FileService
Marketing marketing.MarketingService
Meta meta.MetaService
Scheduler scheduler.SchedulerService
Settings settings.SettingService
Webhooks webhooks.WebhookService
// contains filtered or unexported fields
}
Client creates a struct with services and top level methods that help with interacting with the hubspot API. You should not instantiate this client directly, and instead use the NewClient method instead.
func NewClient ¶
func NewClient(opts ...option.RequestOption) (r Client)
NewClient generates a new client with the default option read from the environment (HUBSPOT_BASE_URL). The option passed in as arguments are applied after these default arguments, and all option will be passed down to the services and requests that this client makes.
func (*Client) Delete ¶
func (r *Client) Delete(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Delete makes a DELETE request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
func (*Client) Execute ¶
func (r *Client) Execute(ctx context.Context, method string, path string, params any, res any, opts ...option.RequestOption) error
Execute makes a request with the given context, method, URL, request params, response, and request options. This is useful for hitting undocumented endpoints while retaining the base URL, auth, retries, and other options from the client.
If a byte slice or an io.Reader is supplied to params, it will be used as-is for the request body.
The params is by default serialized into the body using encoding/json. If your type implements a MarshalJSON function, it will be used instead to serialize the request. If a URLQuery method is implemented, the returned [url.Values] will be used as query strings to the url.
If your params struct uses param.Field, you must provide either [MarshalJSON], [URLQuery], and/or [MarshalForm] functions. It is undefined behavior to use a struct uses param.Field without specifying how it is serialized.
Any "…Params" object defined in this library can be used as the request argument. Note that 'path' arguments will not be forwarded into the url.
The response body will be deserialized into the res variable, depending on its type:
- A pointer to a *http.Response is populated by the raw response.
- A pointer to a byte array will be populated with the contents of the request body.
- A pointer to any other type uses this library's default JSON decoding, which respects UnmarshalJSON if it is defined on the type.
- A nil value will not read the response body.
For even greater flexibility, see option.WithResponseInto and option.WithResponseBodyInto.
func (*Client) Get ¶
func (r *Client) Get(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Get makes a GET request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
func (*Client) Patch ¶
func (r *Client) Patch(ctx context.Context, path string, params any, res any, opts ...option.RequestOption) error
Patch makes a PATCH request with the given URL, params, and optionally deserializes to a response. See [Execute] documentation on the params and response.
type CollectionResponsePropertyGroupNoPaging ¶
type CollectionResponsePropertyGroupNoPaging = shared.CollectionResponsePropertyGroupNoPaging
This is an alias to an internal type.
type ForwardPaging ¶
type ForwardPaging = shared.ForwardPaging
This is an alias to an internal type.
type NextPage ¶
Specifies the paging information needed to retrieve the next set of results in a paginated API response
This is an alias to an internal type.
type ObjectTypeDefinition ¶
type ObjectTypeDefinition = shared.ObjectTypeDefinition
This is an alias to an internal type.
type ObjectTypeDefinitionLabels ¶
type ObjectTypeDefinitionLabels = shared.ObjectTypeDefinitionLabels
This is an alias to an internal type.
type ObjectTypeDefinitionLabelsParam ¶
type ObjectTypeDefinitionLabelsParam = shared.ObjectTypeDefinitionLabelsParam
This is an alias to an internal type.
type ObjectTypeDefinitionPatchParam ¶
type ObjectTypeDefinitionPatchParam = shared.ObjectTypeDefinitionPatchParam
This is an alias to an internal type.
type OptionInputParam ¶
type OptionInputParam = shared.OptionInputParam
This is an alias to an internal type.
type PreviousPage ¶
type PreviousPage = shared.PreviousPage
specifies the paging information needed to retrieve the previous set of results in a paginated API response
This is an alias to an internal type.
type PropertyCreateDataSensitivity ¶
type PropertyCreateDataSensitivity = shared.PropertyCreateDataSensitivity
This is an alias to an internal type.
type PropertyCreateFieldType ¶
type PropertyCreateFieldType = shared.PropertyCreateFieldType
This is an alias to an internal type.
type PropertyCreateNumberDisplayHint ¶
type PropertyCreateNumberDisplayHint = shared.PropertyCreateNumberDisplayHint
This is an alias to an internal type.
type PropertyCreateParam ¶
type PropertyCreateParam = shared.PropertyCreateParam
This is an alias to an internal type.
type PropertyCreateType ¶
type PropertyCreateType = shared.PropertyCreateType
This is an alias to an internal type.
type PropertyDataSensitivity ¶
type PropertyDataSensitivity = shared.PropertyDataSensitivity
Indicates the sensitivity level of the property, such as "non_sensitive", "sensitive", or "highly_sensitive".
This is an alias to an internal type.
type PropertyDateDisplayHint ¶
type PropertyDateDisplayHint = shared.PropertyDateDisplayHint
Controls how date properties are displayed in the HubSpot UI, with options such as 'absolute', 'absolute_with_relative', 'time_since', and 'time_until'.
This is an alias to an internal type.
type PropertyGroup ¶
type PropertyGroup = shared.PropertyGroup
This is an alias to an internal type.
type PropertyGroupCreateParam ¶
type PropertyGroupCreateParam = shared.PropertyGroupCreateParam
This is an alias to an internal type.
type PropertyGroupUpdateParam ¶
type PropertyGroupUpdateParam = shared.PropertyGroupUpdateParam
This is an alias to an internal type.
type PropertyModificationMetadata ¶
type PropertyModificationMetadata = shared.PropertyModificationMetadata
This is an alias to an internal type.
type PropertyNameParam ¶
type PropertyNameParam = shared.PropertyNameParam
This is an alias to an internal type.
type PropertyNumberDisplayHint ¶
type PropertyNumberDisplayHint = shared.PropertyNumberDisplayHint
Hint for how a number property is displayed and validated in HubSpot's UI. Can be: "unformatted", "formatted", "currency", "percentage", "duration", or "probability".
This is an alias to an internal type.
type PropertyValue ¶
type PropertyValue = shared.PropertyValue
Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.
This is an alias to an internal type.
type PropertyValueDataSensitivity ¶
type PropertyValueDataSensitivity = shared.PropertyValueDataSensitivity
The sensitivity level of the property, such as "non_sensitive", "sensitive", and "highly_sensitive".
This is an alias to an internal type.
type PropertyValueParam ¶
type PropertyValueParam = shared.PropertyValueParam
Represents a single custom property of a marketing event, storing its name, value, metadata (like source, timestamp, and sensitivity), and related audit information for tracking changes.
This is an alias to an internal type.
type PropertyValueSource ¶
type PropertyValueSource = shared.PropertyValueSource
The origin of the property value, such as "IMPORT" or "API".
This is an alias to an internal type.
type PublicObjectID ¶
type PublicObjectID = shared.PublicObjectID
Contains the Id of a Public Object
This is an alias to an internal type.
type PublicObjectIDParam ¶
type PublicObjectIDParam = shared.PublicObjectIDParam
Contains the Id of a Public Object
This is an alias to an internal type.
type StandardError ¶
type StandardError = shared.StandardError
Ye olde error
This is an alias to an internal type.
Directories
¶
| Path | Synopsis |
|---|---|
|
encoding/json
Package json implements encoding and decoding of JSON as defined in RFC 7159.
|
Package json implements encoding and decoding of JSON as defined in RFC 7159. |
|
encoding/json/shims
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package.
|
This package provides shims over Go 1.2{2,3} APIs which are missing from Go 1.22, and used by the Go 1.24 encoding/json package. |
|
packages
|
|